<a id="mypy-boto3-codestar"></a>

# mypy-boto3-codestar

[![PyPI - types-aiobotocore-codestar](https://img.shields.io/pypi/v/types-aiobotocore-codestar.svg?color=blue)](https://pypi.org/project/types-aiobotocore-codestar)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-codestar.svg?color=blue)](https://pypi.org/project/types-aiobotocore-codestar)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-codestar?color=blue)](https://pypistats.org/packages/types-aiobotocore-codestar)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.CodeStar 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar.html#CodeStar)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-codestar docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_codestar/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-codestar](#mypy-boto3-codestar)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `CodeStar`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `CodeStar` service.

```bash
python -m pip install types-aiobotocore[codestar]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[codestar]` in your environment:
  `python -m pip install 'types-aiobotocore[codestar]'`

Both type checking and auto-complete should work for `CodeStar` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[codestar]` in your environment:
  `python -m pip install 'types-aiobotocore[codestar]'`

Both type checking and auto-complete should work for `CodeStar` service. No
explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[codestar]` in your environment:
  `python -m pip install 'types-aiobotocore[codestar]'`
- Run `mypy` as usual

Type checking should work for `CodeStar` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[codestar]` in your environment:
  `python -m pip install 'types-aiobotocore[codestar]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `CodeStar` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`CodeStarClient` provides annotations for `session.create_client("codestar")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_codestar import CodeStarClient

session = get_session()
with async session.create_client("codestar") as client:
    client: CodeStarClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_codestar.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_codestar import CodeStarClient
from types_aiobotocore_codestar.paginator import (
    ListProjectsPaginator,
    ListResourcesPaginator,
    ListTeamMembersPaginator,
    ListUserProfilesPaginator,
)

session = get_session()
with async session.create_client("codestar") as client:
    client: CodeStarClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
        list_resources_paginator: ListResourcesPaginator = client.get_paginator("list_resources")
        list_team_members_paginator: ListTeamMembersPaginator = client.get_paginator("list_team_members")
        list_user_profiles_paginator: ListUserProfilesPaginator = client.get_paginator("list_user_profiles")
    ```







### Literals

`types_aiobotocore_codestar.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_codestar.literals import (
    ListProjectsPaginatorName,
    ListResourcesPaginatorName,
    ListTeamMembersPaginatorName,
    ListUserProfilesPaginatorName,
    ServiceName,
    PaginatorName,
)

def check_value(value: ListProjectsPaginatorName) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_codestar.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_codestar.type_defs import (
    AssociateTeamMemberRequestRequestTypeDef,
    AssociateTeamMemberResultTypeDef,
    CodeCommitCodeDestinationTypeDef,
    CodeDestinationTypeDef,
    CodeSourceTypeDef,
    CodeTypeDef,
    CreateProjectRequestRequestTypeDef,
    CreateProjectResultTypeDef,
    CreateUserProfileRequestRequestTypeDef,
    CreateUserProfileResultTypeDef,
    DeleteProjectRequestRequestTypeDef,
    DeleteProjectResultTypeDef,
    DeleteUserProfileRequestRequestTypeDef,
    DeleteUserProfileResultTypeDef,
    DescribeProjectRequestRequestTypeDef,
    DescribeProjectResultTypeDef,
    DescribeUserProfileRequestRequestTypeDef,
    DescribeUserProfileResultTypeDef,
    DisassociateTeamMemberRequestRequestTypeDef,
    GitHubCodeDestinationTypeDef,
    ListProjectsRequestRequestTypeDef,
    ListProjectsResultTypeDef,
    ListResourcesRequestRequestTypeDef,
    ListResourcesResultTypeDef,
    ListTagsForProjectRequestRequestTypeDef,
    ListTagsForProjectResultTypeDef,
    ListTeamMembersRequestRequestTypeDef,
    ListTeamMembersResultTypeDef,
    ListUserProfilesRequestRequestTypeDef,
    ListUserProfilesResultTypeDef,
    PaginatorConfigTypeDef,
    ProjectStatusTypeDef,
    ProjectSummaryTypeDef,
    ResourceTypeDef,
    ResponseMetadataTypeDef,
    S3LocationTypeDef,
    TagProjectRequestRequestTypeDef,
    TagProjectResultTypeDef,
    TeamMemberTypeDef,
    ToolchainSourceTypeDef,
    ToolchainTypeDef,
    UntagProjectRequestRequestTypeDef,
    UpdateProjectRequestRequestTypeDef,
    UpdateTeamMemberRequestRequestTypeDef,
    UpdateTeamMemberResultTypeDef,
    UpdateUserProfileRequestRequestTypeDef,
    UpdateUserProfileResultTypeDef,
    UserProfileSummaryTypeDef,
)

def get_structure() -> AssociateTeamMemberRequestRequestTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-codestar` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-codestar docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_codestar/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
